@@ -3,12 +3,17 @@ import os
 import sys
 from pathlib import Path
 
+
 def setup():
     """Setup environment for Mailman web."""
-    if os.getenv('DJANGO_SETTINGS_MODULE') is not None:
+    django_settings = os.getenv('DJANGO_SETTINGS_MODULE', None)
+    if django_settings is not None:
         return
 
-    MAILMAN_WEB_CONFIG = os.getenv('MAILMAN_WEB_CONFIG', '/etc/mailman3/settings.py')
+    MAILMAN_WEB_CONFIG = os.getenv(
+        'MAILMAN_WEB_CONFIG',
+        '/etc/mailman3/settings.py',
+    )
 
     if not os.path.exists(MAILMAN_WEB_CONFIG):
         print('Mailman web configuration file at {} does not exist'.format(
@@ -18,10 +23,12 @@ def setup():
         sys.exit(1)
 
     config_path = Path(MAILMAN_WEB_CONFIG).resolve()
-    sys.path.append(str(config_path.parent))
 
+    sys.path.append(str(config_path.parent))
+    os.environ['PYTHONPATH'] = str(config_path.parent)
     os.environ['DJANGO_SETTINGS_MODULE'] = config_path.stem
 
+
 def main():
     setup()
 
